==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebRowExportingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowExportingEventArgsDetailDescriptionMetadata } from "./WebRowExportingEventArgsDetailDescriptionMetadata";
import { WebRowExportingEventArgsDescription } from "./WebRowExportingEventArgsDescription";
/**
 * @hidden
 */
var WebRowExportingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRowExportingEventArgsDescriptionMetadata, _super);
    function WebRowExportingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowExportingEventArgsDescriptionMetadata.b = function (a) {
        if (WebRowExportingEventArgsDescriptionMetadata.a == null) {
            WebRowExportingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowExportingEventArgsDescriptionMetadata.c(WebRowExportingEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebRowExportingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebRowExportingEventArgsDescriptionMetadata.a);
        WebRowExportingEventArgsDetailDescriptionMetadata.d(a);
    };
    WebRowExportingEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RowExportingEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebRowExportingEventArgsDetail");
    };
    WebRowExportingEventArgsDescriptionMetadata.d = function (a) {
        WebRowExportingEventArgsDescriptionMetadata.b(a);
        a.aa("WebRowExportingEventArgs", function () { return new WebRowExportingEventArgsDescription(); });
        a.z("WebRowExportingEventArgs", WebRowExportingEventArgsDescriptionMetadata.a);
    };
    WebRowExportingEventArgsDescriptionMetadata.$t = markType(WebRowExportingEventArgsDescriptionMetadata, 'WebRowExportingEventArgsDescriptionMetadata');
    WebRowExportingEventArgsDescriptionMetadata.a = null;
    return WebRowExportingEventArgsDescriptionMetadata;
}(Base));
export { WebRowExportingEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebRowExportingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowExportingEventArgsDetailDescriptionMetadata } from "./WebRowExportingEventArgsDetailDescriptionMetadata";
import { WebRowExportingEventArgsDescription } from "./WebRowExportingEventArgsDescription";
/**
 * @hidden
 */
var WebRowExportingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRowExportingEventArgsDescriptionMetadata, _super);
    function WebRowExportingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowExportingEventArgsDescriptionMetadata.b = function (a) {
        if (WebRowExportingEventArgsDescriptionMetadata.a == null) {
            WebRowExportingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowExportingEventArgsDescriptionMetadata.c(WebRowExportingEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebRowExportingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebRowExportingEventArgsDescriptionMetadata.a);
        WebRowExportingEventArgsDetailDescriptionMetadata.d(a);
    };
    WebRowExportingEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RowExportingEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebRowExportingEventArgsDetail");
    };
    WebRowExportingEventArgsDescriptionMetadata.d = function (a) {
        WebRowExportingEventArgsDescriptionMetadata.b(a);
        a.ac("WebRowExportingEventArgs", function () { return new WebRowExportingEventArgsDescription(); });
        a.ab("WebRowExportingEventArgs", WebRowExportingEventArgsDescriptionMetadata.a);
    };
    WebRowExportingEventArgsDescriptionMetadata.$t = markType(WebRowExportingEventArgsDescriptionMetadata, 'WebRowExportingEventArgsDescriptionMetadata');
    WebRowExportingEventArgsDescriptionMetadata.a = null;
    return WebRowExportingEventArgsDescriptionMetadata;
}(Base));
export { WebRowExportingEventArgsDescriptionMetadata };
